@@ -31,11 +31,11 @@ with 'Lintian::Check';
 sub binary {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     $self->tag('emacsen-common-without-dh-elpa')
-      if ($info->index('usr/lib/emacsen-common/packages/install/')
-        && (not $info->index('usr/share/emacs/site-lisp/elpa-src/')));
+      if ($processable->index('usr/lib/emacsen-common/packages/install/')
+        && (not $processable->index('usr/share/emacs/site-lisp/elpa-src/')));
 
     return;
 }
